@@ -5,9 +5,10 @@ check_solver_optns <- function(solver, solver_optns) {
       "sinkhorn" = list(numIterations = 1e3,
                         epsilon = 0.01,
                         maxErr = 1e-9),
-      "sinkhorn_log" = list(numIterations = 1e3,
+      "sinkhorn_stable" = list(numIterations = 1e3,
                         epsilon = 0.01,
-                        maxErr = 1e-9),
+                        maxErr = 1e-9,
+                        tau = 1e4),
       "transport" = list(fullreturn = TRUE)
     )
 
@@ -15,8 +16,8 @@ check_solver_optns <- function(solver, solver_optns) {
   }
 
   # If options are provided, check correctness for sinkhorn solvers
-  if (solver == "sinkhorn" || solver == "sinkhorn_log") {
-    stopifnot(all(names(solver_optns) %in% c("numIterations", "epsilon", "maxErr")))
+  if (solver == "sinkhorn" || solver == "sinkhorn_stable") {
+    stopifnot(all(names(solver_optns) %in% c("numIterations", "epsilon", "maxErr", "tau")))
 
     if (!exists("numIterations", solver_optns)) {
       solver_optns[["numIterations"]] <- 1e3
@@ -27,6 +28,9 @@ check_solver_optns <- function(solver, solver_optns) {
     if (!exists("maxErr", solver_optns)) {
       solver_optns[["maxErr"]] <- 1e-9
     }
+    if (!exists("tau", solver_optns) && solver == "sinkhorn_stable") {
+      solver_optns[["tau"]] <- 1e5
+    }
 
     return(solver_optns)
   }
