@@ -1,4 +1,4 @@
-#' Calculate Optimal Transport sensitivity indices for multivariate y
+#' Estimate optimal transport sensitivity indices for generic outputs
 #'
 #' @description `ot_indices` calculates sensitivity indices using Optimal
 #'   Transport (OT) for a multivariate output sample `y` with respect to input
@@ -51,10 +51,13 @@
 #'   available CPUs. Check the `ncpus` option in the [boot::boot()] function of
 #'   the boot package.
 #' @param conf (default `0.95`) Number between `0` and `1` representing the
-#'   confidence level. Only considered if `boot = TRUE`.
-#' @param type (default `"norm"`) Method to compute the confidence interval.
-#'   Only considered if `boot = TRUE`. For more information, check the `type`
-#'   option of [boot::boot.ci()].
+#'   default confidence level. Only considered if `boot = TRUE`. Different
+#'   confidence levels can be computed as a postprocessing using
+#'   [confint.gsaot_indices()].
+#' @param type (default `"norm"`) Method to compute the default confidence
+#'   interval. Only considered if `boot = TRUE`. For more information, check the
+#'   `type` argument of [boot::boot.ci()]. Different confidence intervals can be
+#'   computed as a postprocessing using [confint.gsaot_indices()].
 #'
 #' @details ## Solvers
 #'
@@ -114,7 +117,9 @@
 #'   Wasserstein-Bures indices, the Advective, and the Diffusive components.
 #' * `partitions`: a matrix containing the partitions built to calculate the
 #'   sensitivity indices. Each column contains the partition associated to the
-#'   same column in `x`. If `boot = TRUE`, the object contains also:
+#'   same column in `x`.
+#'
+#' If `boot = TRUE`, the object contains also:
 #' * `indices_ci`: a `data.frame` with first column the input, second and third
 #'   columns the lower and upper bound of the confidence interval.
 #' * `inner_statistic_ci`: a list of matrices. Each element of the list contains
@@ -123,6 +128,7 @@
 #'   intervals of the separation measure bound.
 #' * `type`, `conf`: type of confidence interval and confidence level, provided
 #'   as arguments.
+#' * `W_boot`: list of bootstrap objects, one for each input.
 #'
 #' @seealso [ot_indices_1d()], [ot_indices_wb()]
 #'
@@ -295,6 +301,8 @@ ot_indices <- function(x,
     W_ci$input <- names(W)
     IS_ci <- list()
     V_ci <- list()
+
+    W_boot <- list()
   }
 
   # Evaluate the upper bound of the indices (if no boot), otherwise it is
@@ -363,23 +371,23 @@ ot_indices <- function(x,
       }
 
       # Do boostrap estimation stratified by the partitions
-      W_boot <- boot::boot(data = dat,
-                           statistic = ot_boot,
-                           R = R,
-                           strata = strata,
-                           discrete_out = discrete_out,
-                           M = M,
-                           C = C,
-                           y_unique = y_unique,
-                           solver_fun = solver_fun,
-                           solver_optns = solver_optns,
-                           scaling_param = scaling_param,
-                           parallel = parallel,
-                           ncpus = ncpus,
-                           stratified_boot = stratified_boot)
+      W_boot[[k]] <- boot::boot(data = dat,
+                                statistic = ot_boot,
+                                R = R,
+                                strata = strata,
+                                discrete_out = discrete_out,
+                                M = M,
+                                C = C,
+                                y_unique = y_unique,
+                                solver_fun = solver_fun,
+                                solver_optns = solver_optns,
+                                scaling_param = scaling_param,
+                                parallel = parallel,
+                                ncpus = ncpus,
+                                stratified_boot = stratified_boot)
 
       # Transform the results into readable quantities
-      W_stats <- bootstats(W_boot, type = type, conf = conf)
+      W_stats <- bootstats(W_boot[[k]], type = type, conf = conf)
 
       # Save the results
       W[k] <- W_stats$index[1]
@@ -405,7 +413,8 @@ ot_indices <- function(x,
                          IS_ci = IS_ci,
                          R = R,
                          conf = conf,
-                         type = type)
+                         type = type,
+                         W_boot = W_boot)
 
     return(out)
   }
